=============
lesana-search
=============

---------------------------------
search inside a lesana collection
---------------------------------

:Author: valhalla@trueelena.org
:Manual section: 1

SYNOPSIS
========

lesana search [--help] [--collection COLLECTION] [--template TEMPLATE] \
[--offset OFFSET] [--pagesize PAGESIZE] [--all] query [query ...]

DESCRIPTION
===========


OPTIONS
=======

-h, --help
   Prints an help message and exits.
--collection COLLECTION, -c COLLECTION
   The collection to work on. Default is ``.``
--template TEMPLATE, -t TEMPLATE
   Template to use when displaying results
--offset OFFSET
   .
--pagesize PAGESIZE
   .
--all
   Return all available results

